cmoncrawl.processor.pipeline.extractor.BaseExtractor
====================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. autoclass:: BaseExtractor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~BaseExtractor.__init__
      ~BaseExtractor.extract
      ~BaseExtractor.extract_soup
      ~BaseExtractor.filter_raw
      ~BaseExtractor.filter_soup
      ~BaseExtractor.preprocess
   
   

   
   
   